var mainState = {  
    preload: function() {  
        // Here we preload the assets
        this.game.load.image("fondo", "assets/backyard.png");
        this.game.load.image("manzana", "assets/apple.png");
        this.game.load.image("dulce", "assets/candy.png");
        this.game.load.image("rotacion", "assets/rotate.png");
        this.game.load.image("juguete", "assets/rubber_duck.png");
        this.load.spritesheet("mascota", "assets/pet.png", 97, 83, 5, 1, 1);
    },

    create: function() {  
        // Here we create the game
        this.scale.scaleMode = Phaser.ScaleManager.SHOW_ALL;
        this.scale.pageAlignHorizontally = true;
        this.scale.pageAlignVertically = true;

        this.scale.updateLayout(true);
        this.fondo = this.game.add.sprite(0, 0, "fondo");
        this.fondo.inputEnabled = true;
        this.fondo.events.onInputDown.add(this.soltar, this);

        // Mascota
        this.mascota = this.game.add.sprite(100, 400, "mascota", 0);
        this.mascota.animations.add("diversion", [0, 1, 2, 3, 2, 1, 0], 7, false);
        this.mascota.anchor.setTo(0.5);
        this.mascota.customParams = {
        	salud: 100,
        	diversion: 100
        };

        // Manzana
        this.manzana = this.game.add.sprite(72, 570, "manzana");
        this.manzana.anchor.setTo(0.5);
        this.manzana.customParams = {
        	salud: 20
        };
        this.manzana.inputEnabled = true;
        this.manzana.events.onInputDown.add(this.seleccionar, this);

        // Dulce
        this.dulce = this.game.add.sprite(144, 570, "dulce");
        this.dulce.anchor.setTo(0.5);
        this.dulce.customParams = {
        	salud: -10,
        	diversion: 10
        };
        this.dulce.inputEnabled = true;
        this.dulce.events.onInputDown.add(this.seleccionar, this);

        // Juguete
        this.juguete = this.game.add.sprite(216, 570, "juguete");
        this.juguete.anchor.setTo(0.5);
        this.juguete.customParams = {
        	diversion: 30
        };
        this.juguete.inputEnabled = true;
        this.juguete.events.onInputDown.add(this.seleccionar, this);

        // Rotacion
        this.rotacion = this.game.add.sprite(288, 570, "rotacion");
        this.rotacion.anchor.setTo(0.5);
        this.rotacion.inputEnabled = true;
        this.rotacion.events.onInputDown.add(this.rotar, this);

        // Textos
        var style = {
        	font: "20px Arial",
        	fill: "#fff"
        };
        this.game.add.text(10, 20, "Health:", style);
        this,game.add.text(140, 20, "Fun:", style);

        this.healthText = this.game.add.text(80, 20, "", style);
        this.funText = this.game.add.text(185, 20, "", style);
        this.actualizaEstadisticas();

        // Disminuir valores de estadisticas
        this.consumirEstadisticas = this.game.time.events.loop(Phaser.Timer.SECOND * 5, this.reducirPropiedades, this);
        this.consumirEstadisticas.timer.start();

        // No hay nada seleccionado
        this.elementoSeleccionado = null;
    },

    update: function() {  
        // Here we update the game 60 times per second
        if (this.mascota.customParams.salud <= 0 || this.mascota.customParams.diversion <= 0) {
        	this.mascota.customParams.salud = 0;
        	this.mascota.customParams.diversion = 0;
        	this.mascota.frame = 4;
        	this.uiBlocked = true;
        	this.game.time.events.add(2000, this.reiniciar, this);
        }
    },

    rotar: function(sprite, event) {
    	this.elementoSeleccionado = null;
    	sprite.alpha = 0.4;
        if (navigator.vibrate) {
            navigator.vibrate(1000);
        }
    	var mascotaRotacion = game.add.tween(this.mascota);
    	mascotaRotacion.to({
    		angle: "+720"
    	}, 1000);
    	mascotaRotacion.onComplete.add(function() {
    		sprite.alpha = 1;
    	}, this);
    	mascotaRotacion.start();
    },

    seleccionar: function(sprite, event) {
    	sprite.alpha = 0.4;
    	this.elementoSeleccionado = sprite;
    },

    soltar: function(sprite, event) {
    	if (this.elementoSeleccionado) {
    		var x = event.position.x;
    		var y = event.position.y;
    		var nuevoElemento = this.game.add.sprite(x, y, this.elementoSeleccionado.key);
    		nuevoElemento.anchor.setTo(0.5);
    		nuevoElemento.customParams = this.elementoSeleccionado.customParams;
    		this.uiBlocked = true;
    		var moverMascota = game.add.tween(this.mascota);
    		moverMascota.to( {
    			x: x,
    			y: y
    		}, 700);
    		moverMascota.onComplete.add(function() {
    			this.uiBlocked = false;
    			nuevoElemento.destroy();
    			this.mascota.animations.play("diversion");
    			var estadisticas;
    			for (estadisticas in nuevoElemento.customParams) {
    				if (nuevoElemento.customParams.hasOwnProperty(estadisticas)) {
    					this.mascota.customParams[estadisticas] += nuevoElemento.customParams[estadisticas];
    				}
    			}
    			this.actualizaEstadisticas();
    			this.elementoSeleccionado.alpha = 1;
    			this.elementoSeleccionado = null;
    		}, this);
    		moverMascota.start();
    	}
    },

    reiniciar: function() {
    	this.game.state.restart();
    },

    actualizaEstadisticas: function() {
    	this.healthText.text = this.mascota.customParams.salud;
    	this.funText.text = this.mascota.customParams.diversion;
    },

    reducirPropiedades: function () {
    	this.mascota.customParams.salud = Math.max(0, this.mascota.customParams.salud - 10);
    	this.mascota.customParams.diversion = Math.max(0, this.mascota.customParams.diversion - 10);
    	this.actualizaEstadisticas();
    }
};

// Initialize the game and start our state
var game = new Phaser.Game(360, 640, Phaser.AUTO, '');
game.state.add('main', mainState);  
game.state.start('main');